@@ -7,6 +7,7 @@ import hashlib
 from Crypto import Random
 from jinja2 import Template
 from Crypto.Cipher import AES
+from bs4 import BeautifulSoup
 from mkdocs.plugins import BasePlugin
 
 try:
@@ -56,6 +57,7 @@ class encryptContentPlugin(BasePlugin):
         ('tag_encrypted_page', mkdocs.config.config_options.Type(bool, default=False)),
         ('password_button', mkdocs.config.config_options.Type(bool, default=False)),
         ('password_button_text', mkdocs.config.config_options.Type(string_types, default=str(settings['password_button_text']))),
+        ('encrypted_something', mkdocs.config.config_options.Type(dict, default={})),
     )
 
     def __hash_md5__(self, text):
@@ -100,6 +102,7 @@ class encryptContentPlugin(BasePlugin):
             'hljs': self.hljs,
             'remember_password': self.remember_password,
             'disable_cookie_protection': self.disable_cookie_protection,
+            'encrypted_something': self.encrypted_something,
         })
         return decrypt_form
 
@@ -164,6 +167,12 @@ class encryptContentPlugin(BasePlugin):
             if 'password_button_text' in plugin_config.keys():
                 password_button_text = plugin_config.get('password_button_text')
                 setattr(self, 'password_button_text', password_button_text)
+        # Check if encrypted_something feature is enable: encrypt each other html tags targets
+        setattr(self, 'encrypted_something', {})
+        if 'encrypted_something' in plugin_config.keys():
+            encrypted_something = self.config.get('encrypted_something')
+            setattr(self, 'encrypted_something', encrypted_something)
+
 
     def on_page_markdown(self, markdown, page, config, **kwargs):
         """
@@ -212,5 +221,50 @@ class encryptContentPlugin(BasePlugin):
             if self.tag_encrypted_page:
                 # Set attribute on page to identify encrypted page on template rendering
                 setattr(page, 'encrypted', True)
+            if self.encrypted_something:
+                # Set attributes on page to retrieve password on POST context
+                setattr(page, 'password', self.password)
             html = self.__encrypt_content__(html)
         return html
+
+    def on_post_page(self, output_content, page, config, **kwargs):
+        """
+        The post_page event is called after the template is rendered,
+        but before it is written to disc and can be used to alter the output of the page.
+        If an empty string is returned, the page is skipped and nothing is written to disc.
+        :param output_content: output of rendered template as string
+        :param page: mkdocs.nav.Page instance
+        :param config:  global configuration object
+        :return: output of rendered template as string
+        """
+        # Limit this process only if encrypted_something feature is enable *(speedup)*
+        if self.encrypted_something and hasattr(page, 'encrypted') and len(self.encrypted_something) > 0:
+            soup = BeautifulSoup(output_content, 'html.parser')
+            for name, tag in self.encrypted_something.items():
+                #print({'name': name, 'html tag': tag[0], 'type': tag[1]})
+                something_search = soup.findAll(tag[0], { tag[1]: name })
+                if something_search is not None and len(something_search) > 0:
+                    # Loop for multi childs tags on target element
+                    for item in something_search:
+                        # Remove '\n', ' ' useless content generated by bs4 parsing...
+                        item.contents = [content for content in item.contents if not content in ['\n', ' ']]
+                        # Merge the content in case there are several elements
+                        if len(item.contents) > 1:
+                            merge_item = ''.join([str(s) for s in item.contents])
+                        else:
+                            merge_item = item.contents[0]
+                        # Encrypt childs items on target tags with page password
+                        cipher_bundle = self.__encrypt_text_aes__(merge_item, page.password)
+                        encrypted_content = b';'.join(cipher_bundle).decode('ascii')
+                        # Replace initial content with encrypted one
+                        bs4_encrypted_content = BeautifulSoup(encrypted_content, 'html.parser')
+                        item.contents = [bs4_encrypted_content]
+                        if item.has_attr('style'):
+                            if isinstance(item['style'], list):
+                                item['style'].append("display:none")
+                            else:
+                                item['style'] = item['class'] + "display:none"
+                        else:
+                            item['style'] = "display:none"
+            output_content = str(soup)
+        return output_content
\ No newline at end of file
